---
title: Spree 3.3.0
section: release_notes
order: 5
---

## Major/New Features

### Rails 5.1 support

`Spree 3.3` is now compatible with `Rails 5.1` compared to `3.2` which used to run on `Rails 5.0`.
Thanks to that you can start using all of the [new great features available in Rails 5](http://edgeguides.rubyonrails.org/5_1_release_notes.html)

Contributed by [Josh Powell](https://github.com/joshRpowell) & [Spark Solutions](http://sparksolutions.co) & [John Hawthorn](https://github.com/jhawthorn)

### Ruby 2.4 support

Spree now works with Ruby `2.2` (`>= 2.2.7`), `2.3.x` and `2.4.x`.

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/7934)

### Segment.com tracker integration

We've extended Tracker system to include other trackers besides Google Analytics.
First of the bunch is [Segment](http://segment.com/) which enables you to
connect your store with over 200 analytics engines, CRMs, live chats, remarketing platforms,
A/B systems and much more. Now in Spree out of the box! No additional development required!

Developed during a [Spree hackaton](https://www.facebook.com/sparksolutions.co/posts/496593110678871).

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/8157)

### Preventing duplicate values for number fields

We've added unique indexes and uniqueness validation on `number` field for those models:

- `CustomerReturn`
- `Order`
- `Payment`
- `Reimbursement`
- `ReturnAuthorization`
- `Shipment`
- `StockTransfer`

This change will fix records with duplicate numbers. Migration scripts we're take care of that.

**WARNING** migration process can take considerable amount of time, depending on volume of your data

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/7870)

### Added missing indexes and unique indexes

Besides number fields we've added multiple regular & unique indexes that were missing. This will keep data consistency of your app in check and also will boost it performance.

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/7905)

### Add `quantity` to inventory units and split on demand

Optimising Shipments and Inventory Units.

- Creates a single `inventory_unit` per `state`, per `line_item`, per `stock_location` with a `quantity` field indicating inventory units in that state.
- Adds a `return_quantity` field in `ReturnAuthorization` indicating the number of units to be returned/exchanged.
- Split inventory unit to extract the portion/quantity that needs to be returned. This might be further split depending upon stock availability at the time of generating return.
- Changes prioritizer and adjuster to maximise the number of `on_hand` items from available stocks in multiple `stock_locations`
- Change `splitters/weight.rb` to use **Worst Fit** algo.

Contributed by [Vinsol](https://github.com/spree/spree/pull/7790)

### Better Store Credits management in customer Frontend and Admin Panel

Store credit removal feature on spree front-end for partially paid order (with store credit payments). User can remove its store credit payment if additional payment is required/

Admin user can do the same from Admin Panel.

Contributed by [Vinsol](https://github.com/spree/spree/pull/8026)

## Upgrade

### Update your Rails version to 5.1

Please follow the
[official Rails guide](http://edgeguides.rubyonrails.org/upgrading_ruby_on_rails.html#upgrading-from-rails-5-0-to-rails-5-1)
to upgrade your store.

### Update Gemfile

```ruby
gem 'spree', '~> 3.3.0'
gem 'spree_auth_devise', '~> 3.3'
gem 'spree_gateway', '~> 3.3'
```

### Update your extensions

We're changing how extensions dependencies work. Previously you had to match
extension branch to Spree branch. Starting from Spree 3.2 release `master` branch of all
`spree-contrib` extensions should work with Spree >= `3.1` and < `4.0`. Please change
your extensions in Gemfile eg.:

from:

```ruby
gem 'spree_braintree_vzero', github: 'spree-contrib/spree_braintree_vzero', branch: '3-1-stable'
```

to:

```ruby
gem 'spree_braintree_vzero', github: 'spree-contrib/spree_braintree_vzero'
```

### Run `bundle update`

### Install missing migrations

```bash
rails spree:install:migrations
rails spree_auth:install:migrations
rails spree_gateway:install:migrations
```

### Run migrations

```bash
rails db:migrate
```

### Other Gotchas

#### Include `UserMethods` in your `User` class

With this release we're not including this automatically. You need to do it manually if you're not using `spree_auth_devise`.

You need to include `Spree::UserMethods` in your user class, eg.

```ruby
class User
  include UserAddress
  include UserMethods
  include UserPaymentSource
end
```

#### Update `aws-sdk` gem to `>= 2.0`

Spree 3.3 comes with paperclip 5.1 support so if you're using Amazon S3 storage you need to change in your Gemfile, from:

```ruby
gem 'aws-sdk', '< 2.0'
```

to:

```ruby
gem 'aws-sdk', '>= 2.0'
```

and run `bundle update aws-sdk`

In your paperclip configuration you also need to specify
`s3_region` attribute eg. https://github.com/spree/spree/blame/master/guides/content/developer/customization/s3_storage.md#L27

Seel also [RubyThursday episode](https://rubythursday.com/episodes/ruby-snack-27-upgrade-paperclip-and-aws-sdk-in-prep-for-rails-5) walkthrough of upgrading paperclip in your project.

#### Add jquery.validate to your project if you've used it directly from Spree

If your application.js file includes line
`//= require jquery.validate/jquery.validate.min`
you will need to add it this file manually to your project because this library was
[removed from Spree in favour of native HTML5 validation](https://github.com/spree/spree/pull/8173).

#### Noteworthy Changes

Also please review each of the noteworthy changes, and ensure your customizations
or extensions are not effected. If you are affected by a change, and have any
of your own tips please submit a PR to help the next person!

## Full Changelog

You can view the full changes using [Github Compare](https://github.com/spree/spree/compare/3-2-stable...3-3-stable).

## Noteworthy Changes

- Removed `jquery.validate` in favour of HTML5 validation for address on checkout

  [Spark Solutions](https://github.com/spree/spree/pull/8173)

- Remove frontend routes from core, to allow usage without default Spree frontend

  [Spark Solutions](https://github.com/spree/spree/pull/8172)

- Use HTML5 `email_field` on frontend checkout

  [Spark Solutions](https://github.com/spree/spree/pull/8160)

- Frontend views cleanup

  [Spark Solutions](https://github.com/spree/spree/pull/8174)

- `acts_as_list` index starts from 1

  [Sai Ram Kunala](https://github.com/spree/spree/pull/7785) & [Jonathan Kelley](https://github.com/spree/spree/issues/7996)

- API: Remove core dependency on api user db column

  [Viktor Fonic](https://github.com/spree/spree/pull/7912)

- Added missing permission checks in Admin Panel

  [Vinsol](https://github.com/spree/spree/pull/8076)

- Loosen project dependency on `FriendlyId` in Admin Panel and API endpoints

  [Spark Solutions](https://github.com/spree/spree/pull/8072)

- Admin has to confirm clear cache in Admin Panel

  [Spark Solutions](https://github.com/spree/spree/pull/8162)

- Added uniqueness validation added on promotion's code

  [Vinsol](https://github.com/spree/spree/pull/8067)

- Restrict deletion of payment method if associated with payments or credit cards

  [Vinsol](https://github.com/spree/spree/pull/8055)

- Uniqueness validation added on Taxonomy's name and Taxon's permalink

  [Vinsol](https://github.com/spree/spree/pull/8050)

- Admin Panel `field_container` now supports options like content_tag does

  [Fabrizio Monti](https://github.com/spree/spree/pull/8163)

- Simplify `EmailValidator` regexp to align with `Devise.email_regexp`

  [Spark Solutions](https://github.com/spree/spree/pull/8171)

- Schema.org fixes for products microformat data

  [Spark Solutions](https://github.com/spree/spree/pull/8039)

- Allow valid image types to be overridden without deleting validations for `Spree::Image`

  [Tom Chipchase](https://github.com/spree/spree/pull/8176)

- Updated `paperclip` to `~> 5.1.0`

  [Josh Powell](https://github.com/spree/spree/pull/7858)

- Updated `acts-as-taggable-on` to `5.0`

  [Spark Solutions](https://github.com/spree/spree/pull/8015)

- Updated `FriendlyId` to `5.2`

  [Zeke Gabrielse](https://github.com/spree/spree/pull/8005)

- Loosen ActiveMerchant dependency (`~> 1.67`)

  [Justin Grubbs](https://github.com/spree/spree/pull/8081)

- Updated `cancancan` to `2.0`

  [Spark Solutions](https://github.com/spree/spree/pull/8009)

- Updated `jquery-ui-rails` to `6.0.1` & removed unused assets

  [Spark Solutions](https://github.com/spree/spree/pull/8000)

- Removing mutant dependency

  [Spark Solutions](https://github.com/spree/spree/pull/8013)

- Updated `state_machines-activerecord` to `~> 0.5`

  [Spark Solutions](https://github.com/spree/spree/pull/8083)

- Removed previously deprecated `LineItem#invalid_quantity_check`

  [Spark Solutions](https://github.com/spree/spree/pull/8040)

- Removed deprecated automatic `UserMethods` injection

  [Spark Solutions](https://github.com/spree/spree/pull/8031)

- Deprecated `Spree::Calculator::PercentPerItem` & removed `Spree::Calculator::FreeShipping`

  [Spark Solutions](https://github.com/spree/spree/pull/8030)

- Removed minimum length validation on product slug

  [Viktor Fonic](https://github.com/spree/spree/pull/8028)

- Removed `font-awesome-rails` dependency

  [Spark Solutions](https://github.com/spree/spree/pull/7949)

- Deprecate `Shipment#editable_by?` & `Shipment#send_shipped_email`

  [Spark Solutions](https://github.com/spree/spree/pull/8106)

- Deprecate `Variant#having_orders` & `Variant#on_backorder`

  [Spark Solutions](https://github.com/spree/spree/pull/8225)

- Deprecate `DelegateBelongsTo`

  [Spark Solutions](https://github.com/spree/spree/pull/8179)

- Removed unused `jquery.migrate`, `normalize` & `skeleton` assets from Core

  [Spark Solutions](https://github.com/spree/spree/pull/8185)

- Removed `shoulda-matchers` dependency

  [Spark Solutions](https://github.com/spree/spree/pull/8158)
